==> phplist-2.10.5.tgz: lists/admin/lan/fr/import2.php <==
<?php
$lan = array(

'The temporary directory for uploading (%s) is not writable, so import will fail' => 'Le r&eacute;pertoire temporaire pour t&eacute;l&eacute;charger (%s) n&rsquo;est pas accessible en &eacute;criture, l&rsquo;import &eacute;chouera',
'Invalid Email' => 'Email non valide',
'Import cleared' => 'Import r&eacute;ussi',
'Continue' => 'Continuer',
'Reset Import session' => 'Remettre &agrave; z&eacute;ro la session Import',
'File is either too large or does not exist.' => 'Soit le fichier est trop lourd, soit il n&rsquo;existe pas.',
'No file was specified. Maybe the file is too big? ' => 'Aucun fichier n&rsquo;a &eacute;t&eacute; sp&eacute;cifi&eacute;.  Peut-&ecirc;tre que le fichier est trop lourd? ',
'File too big, please split it up into smaller ones' => 'Fichier trop lourd, merci de le diviser en morceaux plus l&eacute;gers',
'Use of wrong characters in filename: ' => 'Utilisation de caract&egrave;res interdits dans le fichier: ',
'Please choose whether to sign up immediately or to send a notification' => 'S&eacute;lectionnez Confirmer d&rsquo;office ou Envoyer email de notification',
'Cannot read %s. file is not readable !' => 'Lecture de %s a &eacute;chou&eacute;. Le fichier n&rsquo;est pas lisible !',
'Something went wrong while uploading the file. Empty file received. Maybe the file is too big, or you have no permissions to read it.' => 'Une erreur est survenue lors du t&eacute;l&eacute;chargement du fichier.  Un fichier vide a &eacute;t&eacute; re&ccedil;u.  Peut-&ecirc;tre que le fichier est trop lourd, ou vous n&rsquo;&ecirc;tes peut-&ecirc;tre pas autoris&eacute; &agrave; le lire.',
'Reading emails from file ... ' => 'Lecture des emails du fichier ... ',
'Error was around here &quot;%s&quot;' => 'Une erreur a &eacute;t&eacute; d&eacute;tect&eacute;e plus ou moins ici &quot;%s&quot;',
'Illegal character was %s' => 'Le caract&egrave;re interdit &eacute;tait %s',
'A character has been found in the import which is not the delimiter indicated, but is likely to be confused for one. Please clean up your import file and try again' => 'Un caract&egrave;re a &eacute;t&eacute; trouv&eacute; dans l&rsquo;import qui n&rsquo;est pas d&eacute;limit&eacute; de la mani&egrave;re qui a &eacute;t&eacute; sp&eacute;cifi&eacute;e, mais qui peut pr&ecirc;ter &agrave; confusion.  Merci de nettoyer le fichier &agrave; importer et r&eacute;essayez',
'ok, %d lines' => 'ok, %d lignes',
'Cannot find column with email, please make sure the column is called &quot;email&quot; and not eg e-mail' => 'La colonne email n&rsquo;a pas &eacute;t&eacute; trouv&eacute;e, assurez-vous que cette colonne s&rsquo;appelle &quot;email&quot; et pas e-mail, par ex.',
'Create new one' => 'Cr&eacute;er nouveau',
'Skip Column' => 'Sauter Colonne',
'Import Attributes' => 'Importer Attributs',
'Continue' => 'Continuer',
'Please identify the target of the following unknown columns' => 'Merci d&rsquo;identifier la cible de plusieurs colonnes inconnues',
'Summary' => 'Sommaire',
'maps to' => 'correpond &agrave;',
'Create new Attribute' => 'Cr&eacute;er nouvel Attribut',
'maps to' => 'correspond &agrave;',
'Skip Column' => 'Sauter Colonne',
'maps to' => 'correspond &agrave',
'%d lines will be imported' => '%d lignes seront import&eacute;es',
'Confirm Import' => 'Confirmer Import',
'Test Output' => 'R&eacute;sultat test',
'Record has no email' => 'Entr&eacute;e ne comporte pas d&rsquo;email',
'Invalid Email' => 'Email non valide',
'clear value' => 'effacer valeur',
'New Attribute' => 'Nouvel Attribut',
'Skip value' => 'Sauter valeur',
'duplicate' => 'double',
'Duplicate Email' => 'Email en double',
' user imported as ' => ' utilisateur import&eacute; sous ',
'duplicate' => 'double',
'duplicate' => 'double',
'Duplicate Email' => 'Email en double',
'All the emails already exist in the database and are member of the lists' => 'Tous les emails existent d&eacute;j&agrave; dans la base de donn&eacute;es et sont inscrits sur les listes',
'%s emails succesfully imported to the database and added to %d lists.' => '%s emails ont &eacute;t&eacute; import&eacute;s avec succ&egrave;s dans la base de donn&eacute;es et ajout&eacute;s &agrave; %d listes.',
'%d emails subscribed to the lists' => '%d emails inscrits aux listes',
'%s emails already existed in the database' => '%s emails existaient d&eacute;j&agrave; dans la base de donn&eacute;es',
'%d Invalid Emails found.' => '%d Emails non valides ont &eacute;t&eacute; trouv&eacute;s.',
'These records were added, but the email has been made up from ' => 'Ces donn&eacute;es ont &eacute;t&eacute; ajout&eacute;es, mais l&rsquo;email a &eacute;t&eacute; invent&eacute; &agrave; partir de ',
'These records were deleted. Check your source and reimport the data. Duplicates will be identified.' => 'Ces donn&eacute;es ont &eacute;t&eacute; supprim&eacute;es. V&eacute;rifier votre source et r&eacute;importez les donn&eacute;es.  Les entr&eacute;es doubles seront identifi&eacute;es.',
'User data was updated for %d users' => 'Donn&eacute;es sur les utilisateurs ont &eacute;t&eacute; mis &agrave; jour pour %d utilisateurs',
'%d users were matched by foreign key, %d by email' => '%d utilisateurs ont &eacute;t&eacute; li&eacute;s par leur cl&eacute; (foreign key), %d par leur email',
'phplist Import Results' => 'r&eacute;sultats d&rsquo;import phplist',
'Test output<br/>If the output looks ok, click %s to submit for real' => 'R&eacute;sultat test<br/>Si le r&eacute;sultat vous semble OK, cliquez %s pour effectuer l&rsquo;op&eacute;ration d&eacute;finitive',
'Confirm Import' => 'Confirmer l&rsquo;Import',
'Import some more emails' => 'Importer d&rsquo;autres emails',
'Adding users to list' => 'Ajout des utilisateurs &agrave; la liste',
'Select the lists to add the emails to' => 'S&eacute;lectionnez les listes auxquelles il faut inscrire les emails',
'No lists available' => 'Pas de listes disponibles',
'Add a list' => 'Ajouter une liste',
'Select the groups to add the users to' => 'S&eacute;lectionnez les groupes auxquels vous ajoutez les utilisateurs',
'automatically added' => 'ajout&eacute;s automatiquement',
 'importintro' => '<p>Le fichier que vous t&eacute;l&eacute;chargez devra comporter les attributs des donn&eacute;es sur la premi&egrave;re ligne.
    Assurez-vous que la colonne email s&rsquo;intitule "email" et pas quelque chose comme "e-mail" ou
    "Email Address".
    La casse ne compte pas (email/Email sont &eacute;quivalents).
    </p>
    Si vous avez une colonne Cl&eacute; &eacute;trang&egrave;re, i.e. "Foreign Key", elle sera utilis&eacute;e pour synchroniser la base externe et la base de donn&eacute;es PHPlist.  Le foreignkey prendra le pas lorsqu&rsquo;il s&rsquo;agira de retrouver un utilisateur existant.  Ceci va ralentir le processus d&rsquo;import. Si vous optez pour ceci, il est possible d&rsquo;avoir des donn&eacute;es sans email, mais une entr&eacute;e "Invalid Email" (email non-valide) sera ajout&eacute;e &agrave; la place. Vous pouvez ensuite retrouver les donn&eacute;es en recherchant tous les "emails non valides".  La taille maximale pour une cl&eacute; &eacute;trang&egrave;re est de 100.
    <br/><br/>
    <b>Avertissement</b>: le fichier doit &ecirc;tre en format texte.  Ne t&eacute;l&eacute;chargez pas un fichier binaire comme un Document Word.
    <br/>',
'uploadlimits' => 'Les limites suivantes sont d&eacute;finies par votre serveur:<br/>
Taille maximale du total des donn&eacute;es envoy&eacute;es au serveur: <b>%s</b><br/>
Taille maximale de chaque fichier: <b>%s</b>
<br/>PHPlist ne peut g&eacute;rer des fichiers de plus de 1Mb',
'testoutput_blurb' => 'Si vous cochez "R&eacute;sultat test", la liste des emails analys&eacute;s s&rsquo;afficheront sur l&rsquo;&eacute;cran, mais la base de donn&eacute;es ne sauvera pas ces donn&eacute;es.  Cette option est utile pour voir si le format de votre fichier est appropri&eacute;.  Cette option n&rsquo;affichera que les 50 premi&egrave;res lignes de donn&eacute;es.',
'warnings_blurb' => 'Si vous cochez "Afficher Avertissements", des avertissements s&rsquo;afficheront pour les donn&eacute;es non valides.  Les avertissements ne seront affich&eacute;s que si vous cochez "R&eacute;sultat test". Ils seront ignor&eacute;s au moment de l&rsquo;import d&eacute;finitif. ',
'omitinvalid_blurb' => 'Si vous cochez "Omettre non valides", les entr&eacute;es non valides ne seront pas ajout&eacute;es.   Les entr&eacute;es non valides sont celles sans email.  Tout autre attribut sera ajout&eacute; automatiquement, par exemple si un pays dans une entr&eacute;e n&rsquo;est pas trouv&eacute;, il sera ajout&eacute; &agrave; la liste des pays.',
'assigninvalid_blurb' => 'Assigner non valides sera utilis&eacute; pour cr&eacute;er un email pour des utilisateurs sans adresse email valide.
Vous pouvez utiliser des valeurs entre [ et ] pour inventer une valeur pour l&rsquo;email. Par exemple, si votre fichier import contient une colonne "Pr&eacute;nom" et une autre "Nom de famille", vous pouvez utiliser
"[pr&eacute;nom] [nom de famille]" pour cr&eacute;er une nouvelle valeur pour l&rsquo;email de cet utilisateur qui contiendra leur pr&eacute;nom et leur nom de famille.
La valeur [number] (nombre) peut &ecirc;tre utilis&eacute;e pour ins&eacute;rer un num&eacute;ro de s&eacute;quence pour l&rsquo;import.',
'overwriteexisting_blurb' => 'Si vous cochez "Ecraser valeurs existantes", les informations sur un utilisateur dans la base de donn&eacute;es seront remplac&eacute;es par l&rsquo;information import&eacute;e.  Les utilisateurs sont li&eacute;es par email ou cl&eacute; &eacute;trang&egrave;re (foreign key).',
'retainold_blurb' => 'Si vous cochez "Garder ancien email utilisateur", s&rsquo;il existe une conflit entre deux emails identiques, le plus ancien sera retenu et le nouveau sera marqu&eacute; "double".  Si vous ne cochez pas cette option, l&rsquo;ancien sera marqu&eacute; "double" et le nouveau prendra le dessus.',
'sendnotification_blurb' => 'Si vous cochez "envoyer email de notification" les utilisateurs que vous ajoutez vont recevoir une demande de confirmation &agrave; la liste, demande &agrave; laquelle il leur faudra r&eacute;pondre. Ceci est recommand&eacute;, car cela vous permettra d&rsquo;identifier des emails non valides',
'phplist Import  Results' => 'R&eacute;sultat de l&rsquo;import phplist',
'File containing emails' => 'Fichier qui contient les emails',
'Field Delimiter' => 'Champs d&eacute;limit&eacute;s par',
'(default is TAB)' => '(TABULATION par d&eacute;faut)',
'Record Delimiter' => 'Entr&eacute;es d&eacute;limit&eacute;es par',
'(default is line break)' => '(retour &agrave; la ligne par d&eacute;faut)',
'Test output' => 'R&eacute;sultat test',
'Show Warnings' => 'Afficher Avertissements',
'Omit Invalid' => 'Omettre non valides',
'Assign Invalid' => 'Assigner non valides',
'Overwrite Existing' => 'Ecraser valeurs existantes',
'Retain Old User Email' => 'Garder ancien email utilisateur',
'Send&nbsp;Notification&nbsp;email' => 'Envoyer email de&nbsp;Notification&nbsp;',
'Make confirmed immediately' => 'Confirmer d&rsquo;office',
'Import' => 'Importer',


);
?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/fr/import2.php <==
<?php
$lan = array(

'The temporary directory for uploading (%s) is not writable, so import will fail' => 'Le r&eacute;pertoire temporaire pour t&eacute;l&eacute;charger (%s) n&rsquo;est pas accessible en &eacute;criture, l&rsquo;import &eacute;chouera',
'Invalid Email' => 'Email non valide',
'Import cleared' => 'Import r&eacute;ussi',
'Continue' => 'Continuer',
'Reset Import session' => 'Remettre &agrave; z&eacute;ro la session Import',
'File is either too large or does not exist.' => 'Soit le fichier est trop lourd, soit il n&rsquo;existe pas.',
'No file was specified. Maybe the file is too big? ' => 'Aucun fichier n&rsquo;a &eacute;t&eacute; sp&eacute;cifi&eacute;.  Peut-&ecirc;tre que le fichier est trop lourd? ',
'File too big, please split it up into smaller ones' => 'Fichier trop lourd, merci de le diviser en morceaux plus l&eacute;gers',
'Use of wrong characters in filename: ' => 'Utilisation de caract&egrave;res interdits dans le fichier: ',
'Please choose whether to sign up immediately or to send a notification' => 'S&eacute;lectionnez Confirmer d&rsquo;office ou Envoyer email de notification',
'Cannot read %s. file is not readable !' => 'Lecture de %s a &eacute;chou&eacute;. Le fichier n&rsquo;est pas lisible !',
'Something went wrong while uploading the file. Empty file received. Maybe the file is too big, or you have no permissions to read it.' => 'Une erreur est survenue lors du t&eacute;l&eacute;chargement du fichier.  Un fichier vide a &eacute;t&eacute; re&ccedil;u.  Peut-&ecirc;tre que le fichier est trop lourd, ou vous n&rsquo;&ecirc;tes peut-&ecirc;tre pas autoris&eacute; &agrave; le lire.',
'Reading emails from file ... ' => 'Lecture des emails du fichier ... ',
'Error was around here &quot;%s&quot;' => 'Une erreur a &eacute;t&eacute; d&eacute;tect&eacute;e plus ou moins ici &quot;%s&quot;',
'Illegal character was %s' => 'Le caract&egrave;re interdit &eacute;tait %s',
'A character has been found in the import which is not the delimiter indicated, but is likely to be confused for one. Please clean up your import file and try again' => 'Un caract&egrave;re a &eacute;t&eacute; trouv&eacute; dans l&rsquo;import qui n&rsquo;est pas d&eacute;limit&eacute; de la mani&egrave;re qui a &eacute;t&eacute; sp&eacute;cifi&eacute;e, mais qui peut pr&ecirc;ter &agrave; confusion.  Merci de nettoyer le fichier &agrave; importer et r&eacute;essayez',
'ok, %d lines' => 'ok, %d lignes',
'Cannot find column with email, please make sure the column is called &quot;email&quot; and not eg e-mail' => 'La colonne email n&rsquo;a pas &eacute;t&eacute; trouv&eacute;e, assurez-vous que cette colonne s&rsquo;appelle &quot;email&quot; et pas e-mail, par ex.',
'Create new one' => 'Cr&eacute;er nouveau',
'Skip Column' => 'Sauter Colonne',
'Import Attributes' => 'Importer Attributs',
'Continue' => 'Continuer',
'Please identify the target of the following unknown columns' => 'Merci d&rsquo;identifier la cible de plusieurs colonnes inconnues',
'Summary' => 'Sommaire',
'maps to' => 'correpond &agrave;',
'Create new Attribute' => 'Cr&eacute;er nouvel Attribut',
'maps to' => 'correspond &agrave;',
'Skip Column' => 'Sauter Colonne',
'maps to' => 'correspond &agrave',
'%d lines will be imported' => '%d lignes seront import&eacute;es',
'Confirm Import' => 'Confirmer Import',
'Test Output' => 'R&eacute;sultat test',
'Record has no email' => 'Entr&eacute;e ne comporte pas d&rsquo;email',
'Invalid Email' => 'Email non valide',
'clear value' => 'effacer valeur',
'New Attribute' => 'Nouvel Attribut',
'Skip value' => 'Sauter valeur',
'duplicate' => 'double',
'Duplicate Email' => 'Email en double',
' user imported as ' => ' utilisateur import&eacute; sous ',
'duplicate' => 'double',
'duplicate' => 'double',
'Duplicate Email' => 'Email en double',
'All the emails already exist in the database and are member of the lists' => 'Tous les emails existent d&eacute;j&agrave; dans la base de donn&eacute;es et sont inscrits sur les listes',
'%s emails succesfully imported to the database and added to %d lists.' => '%s emails ont &eacute;t&eacute; import&eacute;s avec succ&egrave;s dans la base de donn&eacute;es et ajout&eacute;s &agrave; %d listes.',
'%d emails subscribed to the lists' => '%d emails inscrits aux listes',
'%s emails already existed in the database' => '%s emails existaient d&eacute;j&agrave; dans la base de donn&eacute;es',
'%d Invalid Emails found.' => '%d Emails non valides ont &eacute;t&eacute; trouv&eacute;s.',
'These records were added, but the email has been made up from ' => 'Ces donn&eacute;es ont &eacute;t&eacute; ajout&eacute;es, mais l&rsquo;email a &eacute;t&eacute; invent&eacute; &agrave; partir de ',
'These records were deleted. Check your source and reimport the data. Duplicates will be identified.' => 'Ces donn&eacute;es ont &eacute;t&eacute; supprim&eacute;es. V&eacute;rifier votre source et r&eacute;importez les donn&eacute;es.  Les entr&eacute;es doubles seront identifi&eacute;es.',
'User data was updated for %d users' => 'Donn&eacute;es sur les utilisateurs ont &eacute;t&eacute; mis &agrave; jour pour %d utilisateurs',
'%d users were matched by foreign key, %d by email' => '%d utilisateurs ont &eacute;t&eacute; li&eacute;s par leur cl&eacute; (foreign key), %d par leur email',
'phplist Import Results' => 'r&eacute;sultats d&rsquo;import phplist',
'Test output<br/>If the output looks ok, click %s to submit for real' => 'R&eacute;sultat test<br/>Si le r&eacute;sultat vous semble OK, cliquez %s pour effectuer l&rsquo;op&eacute;ration d&eacute;finitive',
'Confirm Import' => 'Confirmer l&rsquo;Import',
'Import some more emails' => 'Importer d&rsquo;autres emails',
'Adding users to list' => 'Ajout des utilisateurs &agrave; la liste',
'Select the lists to add the emails to' => 'S&eacute;lectionnez les listes auxquelles il faut inscrire les emails',
'No lists available' => 'Pas de listes disponibles',
'Add a list' => 'Ajouter une liste',
'Select the groups to add the users to' => 'S&eacute;lectionnez les groupes auxquels vous ajoutez les utilisateurs',
'automatically added' => 'ajout&eacute;s automatiquement',
 'importintro' => '<p class="information">Le fichier que vous t&eacute;l&eacute;chargez devra comporter les attributs des donn&eacute;es sur la premi&egrave;re ligne.
    Assurez-vous que la colonne email s&rsquo;intitule "email" et pas quelque chose comme "e-mail" ou
    "Email Address".
    La casse ne compte pas (email/Email sont &eacute;quivalents).
    </p>
    Si vous avez une colonne Cl&eacute; &eacute;trang&egrave;re, i.e. "Foreign Key", elle sera utilis&eacute;e pour synchroniser la base externe et la base de donn&eacute;es PHPlist.  Le foreignkey prendra le pas lorsqu&rsquo;il s&rsquo;agira de retrouver un utilisateur existant.  Ceci va ralentir le processus d&rsquo;import. Si vous optez pour ceci, il est possible d&rsquo;avoir des donn&eacute;es sans email, mais une entr&eacute;e "Invalid Email" (email non-valide) sera ajout&eacute;e &agrave; la place. Vous pouvez ensuite retrouver les donn&eacute;es en recherchant tous les "emails non valides".  La taille maximale pour une cl&eacute; &eacute;trang&egrave;re est de 100.
    <br/><br/>
    <b>Avertissement</b>: le fichier doit &ecirc;tre en format texte.  Ne t&eacute;l&eacute;chargez pas un fichier binaire comme un Document Word.
    <br/>',
'uploadlimits' => 'Les limites suivantes sont d&eacute;finies par votre serveur:<br/>
Taille maximale du total des donn&eacute;es envoy&eacute;es au serveur: <b>%s</b><br/>
Taille maximale de chaque fichier: <b>%s</b>
<br/>PHPlist ne peut g&eacute;rer des fichiers de plus de 1Mb',
'testoutput_blurb' => 'Si vous cochez "R&eacute;sultat test", la liste des emails analys&eacute;s s&rsquo;afficheront sur l&rsquo;&eacute;cran, mais la base de donn&eacute;es ne sauvera pas ces donn&eacute;es.  Cette option est utile pour voir si le format de votre fichier est appropri&eacute;.  Cette option n&rsquo;affichera que les 50 premi&egrave;res lignes de donn&eacute;es.',
'warnings_blurb' => 'Si vous cochez "Afficher Avertissements", des avertissements s&rsquo;afficheront pour les donn&eacute;es non valides.  Les avertissements ne seront affich&eacute;s que si vous cochez "R&eacute;sultat test". Ils seront ignor&eacute;s au moment de l&rsquo;import d&eacute;finitif. ',
'omitinvalid_blurb' => 'Si vous cochez "Omettre non valides", les entr&eacute;es non valides ne seront pas ajout&eacute;es.   Les entr&eacute;es non valides sont celles sans email.  Tout autre attribut sera ajout&eacute; automatiquement, par exemple si un pays dans une entr&eacute;e n&rsquo;est pas trouv&eacute;, il sera ajout&eacute; &agrave; la liste des pays.',
'assigninvalid_blurb' => 'Assigner non valides sera utilis&eacute; pour cr&eacute;er un email pour des utilisateurs sans adresse email valide.
Vous pouvez utiliser des valeurs entre [ et ] pour inventer une valeur pour l&rsquo;email. Par exemple, si votre fichier import contient une colonne "Pr&eacute;nom" et une autre "Nom de famille", vous pouvez utiliser
"[pr&eacute;nom] [nom de famille]" pour cr&eacute;er une nouvelle valeur pour l&rsquo;email de cet utilisateur qui contiendra leur pr&eacute;nom et leur nom de famille.
La valeur [number] (nombre) peut &ecirc;tre utilis&eacute;e pour ins&eacute;rer un num&eacute;ro de s&eacute;quence pour l&rsquo;import.',
'overwriteexisting_blurb' => 'Si vous cochez "Ecraser valeurs existantes", les informations sur un utilisateur dans la base de donn&eacute;es seront remplac&eacute;es par l&rsquo;information import&eacute;e.  Les utilisateurs sont li&eacute;es par email ou cl&eacute; &eacute;trang&egrave;re (foreign key).',
'retainold_blurb' => 'Si vous cochez "Garder ancien email utilisateur", s&rsquo;il existe une conflit entre deux emails identiques, le plus ancien sera retenu et le nouveau sera marqu&eacute; "double".  Si vous ne cochez pas cette option, l&rsquo;ancien sera marqu&eacute; "double" et le nouveau prendra le dessus.',
'sendnotification_blurb' => 'Si vous cochez "envoyer email de notification" les utilisateurs que vous ajoutez vont recevoir une demande de confirmation &agrave; la liste, demande &agrave; laquelle il leur faudra r&eacute;pondre. Ceci est recommand&eacute;, car cela vous permettra d&rsquo;identifier des emails non valides',
'phplist Import  Results' => 'R&eacute;sultat de l&rsquo;import phplist',
'File containing emails' => 'Fichier qui contient les emails',
'Field Delimiter' => 'Champs d&eacute;limit&eacute;s par',
'(default is TAB)' => '(TABULATION par d&eacute;faut)',
'Record Delimiter' => 'Entr&eacute;es d&eacute;limit&eacute;es par',
'(default is line break)' => '(retour &agrave; la ligne par d&eacute;faut)',
'Test output' => 'R&eacute;sultat test',
'Show Warnings' => 'Afficher Avertissements',
'Omit Invalid' => 'Omettre non valides',
'Assign Invalid' => 'Assigner non valides',
'Overwrite Existing' => 'Ecraser valeurs existantes',
'Retain Old User Email' => 'Garder ancien email utilisateur',
'Send&nbsp;Notification&nbsp;email' => 'Envoyer email de&nbsp;Notification&nbsp;',
'Make confirmed immediately' => 'Confirmer d&rsquo;office',
'Import' => 'Importer',


);
?>
